==> haskell-regex-tdfa-1.2.2-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-tdfa
version: 1.2.2
id: regex-tdfa-1.2.2-LXrPID2GWRYz5rkILVGL8
key: regex-tdfa-1.2.2-LXrPID2GWRYz5rkILVGL8
license: BSD3
copyright: Copyright (c) 2007, Christopher Kuklewicz
maintainer: Artyom <yom@artyom.me>, Christopher Kuklewicz <TextRegexLazy@personal.mightyreason.com>
stability: Seems to work, but not POSIX yet
homepage: https://github.com/ChrisKuklewicz/regex-tdfa
synopsis: Replaces/Enhances Text.Regex
description:
    A new all Haskell "tagged" DFA regex engine, inspired by libtre
category: Text
author: Christopher Kuklewicz
exposed: True
indefinite: False
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.NewDFA.Tester Text.Regex.TDFA.NewDFA.Uncons
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
hidden-modules: Paths_regex_tdfa
abi: 49cee3c3b864e7a4b170da8a226077c5
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-tdfa-1.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-tdfa-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/regex-tdfa-1.2.2
hs-libraries: HSregex-tdfa-1.2.2-LXrPID2GWRYz5rkILVGL8
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    ghc-prim-0.5.1.1 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1
    regex-base-0.93.2-rcKBNTI69reeBx0eaPBC
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             ghc-prim-0.5.1.1=c8f3d173544d1472727fce7b0518abda
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             parsec-3.1.11-4HFX6l6YojG1oyYQULsuQ1=ac5e6b578591765d59beabaa71c9486d
             regex-base-0.93.2-rcKBNTI69reeBx0eaPBC=3a05b32d0b549c5eb87dc4762955a2ed
haddock-interfaces: /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-tdfa-1.2.2-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-tdfa
version: 1.2.2
id: regex-tdfa-1.2.2-JGrSDGN9OzgIG6BjzD8Db2
key: regex-tdfa-1.2.2-JGrSDGN9OzgIG6BjzD8Db2
license: BSD3
copyright: Copyright (c) 2007, Christopher Kuklewicz
maintainer: Artyom <yom@artyom.me>, Christopher Kuklewicz <TextRegexLazy@personal.mightyreason.com>
stability: Seems to work, but not POSIX yet
homepage: https://github.com/ChrisKuklewicz/regex-tdfa
synopsis: Replaces/Enhances Text.Regex
description:
    A new all Haskell "tagged" DFA regex engine, inspired by libtre
category: Text
author: Christopher Kuklewicz
exposed: True
indefinite: False
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.NewDFA.Tester Text.Regex.TDFA.NewDFA.Uncons
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
hidden-modules: Paths_regex_tdfa
abi: 8d3e8eb4f34816c1c27ca653d7421dfa
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-tdfa-1.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-tdfa-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/regex-tdfa-1.2.2
hs-libraries: HSregex-tdfa-1.2.2-JGrSDGN9OzgIG6BjzD8Db2
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    ghc-prim-0.5.1.1 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7
    regex-base-0.93.2-rcKBNTI69reeBx0eaPBC
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             ghc-prim-0.5.1.1=c8f3d173544d1472727fce7b0518abda
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7=de60442ea6c5324e39bc534a733c07dd
             regex-base-0.93.2-rcKBNTI69reeBx0eaPBC=3a05b32d0b549c5eb87dc4762955a2ed
haddock-interfaces: /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
